This is a live mirror of the Perl 5 development currently hosted at https://github.com/perl/perl5
Fix Cwd::getcwd() not being tainted, as noticed
[perl5.git] / xsutils.c
index 1a95191..81bb2fc 100644 (file)
--- a/xsutils.c
+++ b/xsutils.c
@@ -7,12 +7,12 @@
  */
 
 /* package attributes; */
-void XS_attributes__warn_reserved(pTHXo_ CV *cv);
-void XS_attributes_reftype(pTHXo_ CV *cv);
-void XS_attributes__modify_attrs(pTHXo_ CV *cv);
-void XS_attributes__guess_stash(pTHXo_ CV *cv);
-void XS_attributes__fetch_attrs(pTHXo_ CV *cv);
-void XS_attributes_bootstrap(pTHXo_ CV *cv);
+void XS_attributes__warn_reserved(pTHX_ CV *cv);
+void XS_attributes_reftype(pTHX_ CV *cv);
+void XS_attributes__modify_attrs(pTHX_ CV *cv);
+void XS_attributes__guess_stash(pTHX_ CV *cv);
+void XS_attributes__fetch_attrs(pTHX_ CV *cv);
+void XS_attributes_bootstrap(pTHX_ CV *cv);
 
 
 /*
@@ -38,7 +38,7 @@ Perl_boot_core_xsutils(pTHX)
 #include "XSUB.h"
 
 static int
-modify_SV_attributes(pTHXo_ SV *sv, SV **retlist, SV **attrlist, int numattrs)
+modify_SV_attributes(pTHX_ SV *sv, SV **retlist, SV **attrlist, int numattrs)
 {
     SV *attr;
     char *name;
@@ -85,11 +85,11 @@ modify_SV_attributes(pTHXo_ SV *sv, SV **retlist, SV **attrlist, int numattrs)
                    }
                    break;
                case 's':
-                   if (strEQ(name, "shared")) {
+      if (strEQ(name, "unique")) {
                        if (negated)
-                           GvSHARED_off(CvGV((CV*)sv));
+                           GvUNIQUE_off(CvGV((CV*)sv));
                        else
-                           GvSHARED_on(CvGV((CV*)sv));
+                           GvUNIQUE_on(CvGV((CV*)sv));
                        continue;
                    }
                    break;
@@ -102,8 +102,8 @@ modify_SV_attributes(pTHXo_ SV *sv, SV **retlist, SV **attrlist, int numattrs)
               case 6:
                switch (*name) {
                   case 's':
-                   if (strEQ(name, "shared")) {
-                        /* toke.c has already marked as GvSHARED */
+      if (strEQ(name, "unique")) {
+                        /* toke.c has already marked as GVf_UNIQUE */
                         continue;
                     }
                 }
@@ -155,7 +155,7 @@ usage:
        goto usage;
     sv = SvRV(rv);
     if (items > 1)
-       XSRETURN(modify_SV_attributes(aTHXo_ sv, &ST(0), &ST(1), items-1));
+       XSRETURN(modify_SV_attributes(aTHX_ sv, &ST(0), &ST(1), items-1));
 
     XSRETURN(0);
 }
@@ -189,8 +189,8 @@ usage:
 #endif
        if (cvflags & CVf_METHOD)
            XPUSHs(sv_2mortal(newSVpvn("method", 6)));
-        if (GvSHARED(CvGV((CV*)sv)))
-           XPUSHs(sv_2mortal(newSVpvn("shared", 6)));
+        if (GvUNIQUE(CvGV((CV*)sv)))
+     XPUSHs(sv_2mortal(newSVpvn("unique", 6)));
        break;
     default:
        break;
@@ -231,10 +231,9 @@ usage:
        HV *stash = Nullhv;
        switch (SvTYPE(sv)) {
        case SVt_PVCV:
-           if (CvGV(sv) && isGV(CvGV(sv)) && GvSTASH(CvGV(sv)) &&
-                           HvNAME(GvSTASH(CvGV(sv))))
+           if (CvGV(sv) && isGV(CvGV(sv)) && GvSTASH(CvGV(sv)))
                stash = GvSTASH(CvGV(sv));
-           else if (/* !CvANON(sv) && */ CvSTASH(sv) && HvNAME(CvSTASH(sv)))
+           else if (/* !CvANON(sv) && */ CvSTASH(sv))
                stash = CvSTASH(sv);
            break;
        case SVt_PVMG:
@@ -242,7 +241,7 @@ usage:
                break;
            /*FALLTHROUGH*/
        case SVt_PVGV:
-           if (GvGP(sv) && GvESTASH((GV*)sv) && HvNAME(GvESTASH((GV*)sv)))
+           if (GvGP(sv) && GvESTASH((GV*)sv))
                stash = GvESTASH((GV*)sv);
            break;
        default: